# API Reference

## Models

```{eval-rst}
.. autoclass:: getpaid.abstracts.AbstractOrder
   :members:

.. autoclass:: getpaid.abstracts.AbstractPayment
   :members:
```

## Processor

```{eval-rst}
.. autoclass:: getpaid.processor.BaseProcessor
   :members:
   :show-inheritance:
```

## Registry

```{eval-rst}
.. autoclass:: getpaid.registry.DjangoPluginRegistry
   :members:
```

## Enums and Types

```{eval-rst}
.. automodule:: getpaid.types
   :members:
   :undoc-members:
```

## Exceptions

```{eval-rst}
.. automodule:: getpaid.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
```

## Views

```{eval-rst}
.. automodule:: getpaid.views
   :members:
```
